==> mongoose-types-1.0.1.tgz: package/tests/url.test.js <==
require('should');
var mongoose = require('mongoose')
  , Schema = mongoose.Schema
  , db = mongoose.createConnection('mongodb://localhost/mongoose_types_tests');

require("../").loadTypes(mongoose, 'url');

var WebpageSchema = new Schema({
  url: mongoose.SchemaTypes.Url
});

mongoose.model('Webpage', WebpageSchema);
var Webpage;

module.exports = {
  before: function(done){
    Webpage = db.model('Webpage', WebpageSchema);
    Webpage.remove({}, function (err) {
      done();
    });
  },
  'test invalid url validation': function (done) {
    var webpage = new Webpage({url: 'file:///home/'});
    webpage.save(function (err) {
      throw err;
      err.should.equal('url is invalid');
      webpage.isNew.should.be.true;
      done();
    });
  },
  'test valid url validation': function (done) {
    var webpage = new Webpage({ url: 'http://www.google.com/' });
    webpage.save(function (err) {
      err.should.eql(null);
      webpage.isNew.should.be.false;
      done();
    });
  },
  'url normalization should remove www.': function (done) {
    var webpage = new Webpage({ url: 'http://www.google.com/'});
    webpage.save(function (err) {
      webpage.url.should.equal('http://google.com/');
      Webpage.findById(webpage._id, function (err, refreshed) {
        refreshed.url.should.equal('http://google.com/');
        done();
      });
    });
  },
  'url normalization should add a trailing slash': function (done) {
    var webpage = new Webpage({ url: 'http://google.com'});
    webpage.save(function (err) {
      webpage.url.should.equal('http://google.com/');
      Webpage.findById(webpage._id, function (err, refreshed) {
        refreshed.url.should.equal('http://google.com/');
        done();
      });
    });
  },
  teardown: function(){
    db.close();
  }
};

==> mongoose-types-1.0.3.tgz: package/tests/url.test.js <==
require('should');
var mongoose = require('mongoose')
  , Schema = mongoose.Schema
  , db = mongoose.createConnection('mongodb://localhost/mongoose_types_tests');

require("../").loadTypes(mongoose, 'url');

var WebpageSchema = new Schema({
  url: mongoose.SchemaTypes.Url
});

mongoose.model('Webpage', WebpageSchema);
var Webpage;

module.exports = {
  before: function(){
    Webpage = db.model('Webpage', WebpageSchema);
    Webpage.remove({}, function (err) {});
  },
  'test invalid url validation': function () {
    var webpage = new Webpage({url: 'file:///home/'});
    webpage.save(function (err) {
      err.message.should.equal('Validator "url is invalid" failed for path url');
      webpage.isNew.should.be.true;
    });
  },
  'test valid url validation': function () {
    var webpage = new Webpage({ url: 'http://www.google.com/' });
    webpage.save(function (err) {
      err.should.eql(null);
      webpage.isNew.should.be.false;
    });
  },
  'url normalization should remove www.': function () {
    var webpage = new Webpage({ url: 'http://www.google.com/'});
    webpage.save(function (err) {
      webpage.url.should.equal('http://google.com/');
      Webpage.findById(webpage._id, function (err, refreshed) {
        refreshed.url.should.equal('http://google.com/');
      });
    });
  },
  'url normalization should add a trailing slash': function () {
    var webpage = new Webpage({ url: 'http://google.com'});
    webpage.save(function (err) {
      webpage.url.should.equal('http://google.com/');
      Webpage.findById(webpage._id, function (err, refreshed) {
        refreshed.url.should.equal('http://google.com/');
      });
    });
  },
  teardown: function(){
    db.close();
  }
};
